@@ -186,8 +186,8 @@ def _create_and_check_configuration(
     "--version",
     is_flag=False,
     type=click.Choice([kind.value for kind in command_arguments.VersionKind]),
-    flag_value=command_arguments.VersionKind.CLIENT_AND_BINARY,
-    default=command_arguments.VersionKind.NONE,
+    flag_value=command_arguments.VersionKind.CLIENT_AND_BINARY.value,
+    default=command_arguments.VersionKind.NONE.value,
     help="Print the versions of Pyre.",
 )
 @click.option("--debug/--no-debug", default=False, hidden=True)
@@ -426,8 +426,8 @@ def pyre(
     "--version",
     is_flag=False,
     type=click.Choice([kind.value for kind in command_arguments.VersionKind]),
-    flag_value=command_arguments.VersionKind.CLIENT_AND_BINARY,
-    default=command_arguments.VersionKind.NONE,
+    flag_value=command_arguments.VersionKind.CLIENT_AND_BINARY.value,
+    default=command_arguments.VersionKind.NONE.value,
     help="Print the versions of Pysa.",
 )
 @click.option(
@@ -440,6 +440,11 @@ def pyre(
     type=click.Choice([kind.value for kind in command_arguments.TaintOutputFormat]),
     help="Format of the taint output file(s).",
 )
+@click.option(
+    "--pyrefly-results",
+    type=click.Path(),
+    help="Directory to pyrefly results (pyrefly --report-pysa).",
+)
 @click.option(
     "--dump-call-graph",
     type=str,
@@ -626,6 +631,7 @@ def analyze(
     version: command_arguments.VersionKind,
     save_results_to: Optional[str],
     output_format: Optional[str],
+    pyrefly_results: Optional[str],
     dump_call_graph: Optional[str],
     repository_root: Optional[str],
     rule: Iterable[int],
@@ -712,6 +718,7 @@ def analyze(
                 if output_format is not None
                 else None
             ),
+            pyrefly_results=pyrefly_results,
             sequential=command_argument.sequential,
             taint_models_path=list(taint_models_path),
             use_cache=use_cache,
